@@ -27,6 +27,7 @@ typedef struct {
 	JcatContext *context;
 	gboolean basename;
 	gboolean disable_time_checks;
+	gboolean only_pq;
 	gchar *prefix;
 	gchar *appstream_id;
 	JcatBlobKind kind;
@@ -370,6 +371,7 @@ jcat_tool_import(JcatToolPrivate *priv, gchar **values, GError **error)
 static gboolean
 jcat_tool_self_sign(JcatToolPrivate *priv, gchar **values, GError **error)
 {
+	JcatSignFlags flags = JCAT_SIGN_FLAG_NONE;
 	g_autoptr(GBytes) source = NULL;
 	g_autoptr(GFile) gfile = NULL;
 	g_autoptr(JcatBlob) blob = NULL;
@@ -422,10 +424,12 @@ jcat_tool_self_sign(JcatToolPrivate *priv, gchar **values, GError **error)
 	/* sign with this kind */
 	if (priv->kind == JCAT_BLOB_KIND_UNKNOWN)
 		priv->kind = JCAT_BLOB_KIND_PKCS7;
+	if (priv->only_pq)
+		flags |= JCAT_SIGN_FLAG_USE_PQ;
 	engine = jcat_context_get_engine(priv->context, priv->kind, error);
 	if (engine == NULL)
 		return FALSE;
-	blob = jcat_engine_self_sign(engine, source, JCAT_SIGN_FLAG_NONE, error);
+	blob = jcat_engine_self_sign(engine, source, flags, error);
 	if (blob == NULL)
 		return FALSE;
 	if (priv->appstream_id != NULL)
@@ -601,6 +605,8 @@ jcat_tool_verify_item(JcatToolPrivate *priv, JcatItem *item, GError **error)
 		}
 		if (priv->disable_time_checks)
 			flags |= JCAT_VERIFY_FLAG_DISABLE_TIME_CHECKS;
+		if (priv->only_pq)
+			flags |= JCAT_VERIFY_FLAG_ONLY_PQ;
 		result = jcat_context_verify_blob(priv->context,
 						  blob_source,
 						  blob,
@@ -761,8 +767,8 @@ main(int argc, char *argv[])
 	g_autofree gchar *kind = NULL;
 	g_autofree gchar *target = NULL;
 	g_autofree gchar *prefix = NULL;
-	g_autofree gchar *public_key = NULL;
-	g_autofree gchar *public_keys = NULL;
+	g_auto(GStrv) public_key = NULL;
+	g_auto(GStrv) public_keys = NULL;
 	g_autoptr(JcatToolPrivate) priv = g_new0(JcatToolPrivate, 1);
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GOptionContext) context = NULL;
@@ -789,17 +795,24 @@ main(int argc, char *argv[])
 	     &priv->disable_time_checks,
 	     _("Disable time checks when verifying"),
 	     NULL},
+	    {"only-pq",
+	     'v',
+	     0,
+	     G_OPTION_ARG_NONE,
+	     &priv->only_pq,
+	     _("Only consider post-quantum signatures"),
+	     NULL},
 	    {"public-key",
 	     '\0',
 	     0,
-	     G_OPTION_ARG_STRING,
+	     G_OPTION_ARG_STRING_ARRAY,
 	     &public_key,
 	     _("Location of public key used for verification"),
 	     NULL},
 	    {"public-keys",
 	     '\0',
 	     0,
-	     G_OPTION_ARG_STRING,
+	     G_OPTION_ARG_STRING_ARRAY,
 	     &public_keys,
 	     _("Location of public key directories used for verification"),
 	     NULL},
@@ -925,10 +938,14 @@ main(int argc, char *argv[])
 	priv->appstream_id = g_strdup(appstream_id);
 	priv->prefix = g_strdup(prefix != NULL ? prefix : ".");
 	priv->context = jcat_context_new();
-	if (public_key != NULL)
-		jcat_context_add_public_key(priv->context, public_key);
-	if (public_keys != NULL)
-		jcat_context_add_public_keys(priv->context, public_keys);
+	if (public_key != NULL) {
+		for (guint i = 0; public_key[i] != NULL; i++)
+			jcat_context_add_public_key(priv->context, public_key[i]);
+	}
+	if (public_keys != NULL) {
+		for (guint i = 0; public_keys[i] != NULL; i++)
+			jcat_context_add_public_keys(priv->context, public_keys[i]);
+	}
 	if (keyring_path != NULL)
 		jcat_context_set_keyring_path(priv->context, keyring_path);
 	if (kind != NULL) {
